@@ -353,7 +353,7 @@ def e_des_prep(B, C, Z, P, e_order, e_lags, res, sc_pred, Y_donors, out_feat, J,
         if e_lags > 0:
             B_lags = pandas.DataFrame(None, index=B.index)
             P_lags = pandas.DataFrame(None, index=P.index)
-    
+
             B_diff = B - B.groupby('feature').shift(1)
             aux = B.iloc[B.index.get_level_values('feature') == outcome_var]
             if coig_data is False:
@@ -364,9 +364,9 @@ def e_des_prep(B, C, Z, P, e_order, e_lags, res, sc_pred, Y_donors, out_feat, J,
                 df1 = aux.iloc[(len(aux) - e_lags - 1):len(aux)]
                 df2 = P.iloc[:, 0:J]
                 P_aug = pandas.concat([df1, df2], axis=0)
-    
+
             P_aug_diff = P_aug - P_aug.shift(1)
-    
+
             for ll in range(1, e_lags + 1):
                 if coig_data is False:
                     B_lags = pandas.concat([B_lags,
@@ -378,25 +378,25 @@ def e_des_prep(B, C, Z, P, e_order, e_lags, res, sc_pred, Y_donors, out_feat, J,
                                            B_diff.loc[:, index_w].groupby('feature').shift(ll)], axis=1)
                     P_lags = pandas.concat([P_lags,
                                            P_aug_diff.shift(ll).iloc[(e_lags + 1):, ].loc[:, index_w]], axis=1)
-    
+
             e_des_0 = pandas.concat([e_des_0, B_lags], axis=1)
             e_des_1 = pandas.concat([e_des_1, P_lags], axis=1)
-    
+
         e_des_0 = e_des_0.loc[(outcome_var,), ]
-    
+
         if e_design is not None:
             if not isinstance(e_design, (pandas.DataFrame, numpy.ndarray)):
                 raise Exception("The object e_design should be a dataframe or a matrix!")
-    
+
             if isinstance(e_design, numpy.ndarray):
                 e_design = pandas.DataFrame(e_design,
                                             index=res.index,
                                             columns=res.columns)
-    
+
             if len(e_design) != len(e_res):
                 raise Exception("The object e_design has " + len(e_design) + " rows when " +
                                 len(e_res) + " where expected!")
-    
+
             e_des_0 = e_design
 
     return e_res, e_des_0, e_des_1
@@ -452,10 +452,10 @@ def df_EST(w_constr, w, A, B, J, KM):
         df = J
 
     elif (w_constr['name'] == "lasso") or ((w_constr['p'] == "L1") and (w_constr['dir'] == "<=")):
-        df = sum(abs(w.iloc[:,0].values) >= 1e-6)
+        df = sum(abs(w.iloc[:, 0].values) >= 1e-6)
 
     elif (w_constr['name'] == "simplex") or ((w_constr['p'] == "L1") and (w_constr['dir'] == "==")):
-        df = sum(abs(w.iloc[:,0].values) >= 1e-6) - 1
+        df = sum(abs(w.iloc[:, 0].values) >= 1e-6) - 1
 
     elif (w_constr['name'] == "ridge") or (w_constr["p"] == "L2"):
         d = numpy.linalg.svd(B)[1]
@@ -575,10 +575,18 @@ def scpi_in_simul(i, beta, Sigma_root, Q, P, J, KM, w_lb_est,
                 opt.set_ftol_abs(opt_dict['ftol_abs'])
                 opt.set_maxeval(opt_dict['maxeval'])
 
-                x = opt.optimize(x0)
-
-                alert = opt.last_optimize_result() < 0 or opt.last_optimize_result() >= 5
-                flag = checkConstraints(x, dire, beta, Q, G, J, KM, QQ, p_int, 1e-2, 1e-2)
+                try:
+                    x = opt.optimize(x0)
+                    alert = opt.last_optimize_result() < 0 or opt.last_optimize_result() >= 5
+                    flag = checkConstraints(x, dire, beta, Q, G, J, KM, QQ, p_int, 1e-6, 1e-6)
+                except nlopt.RoundoffLimited:
+                    try:
+                        x = opt.optimize(x0)
+                        alert = opt.last_optimize_result() < 0 or opt.last_optimize_result() >= 5
+                        flag = checkConstraints(x, dire, beta, Q, G, J, KM, QQ, p_int, 1e-6, 1e-6)
+                    except nlopt.RoundoffLimited:
+                        alert = True
+                        flag = True
 
                 if alert is True or flag is True:
                     res_lb.append(numpy.nan)
@@ -636,10 +644,19 @@ def scpi_in_simul(i, beta, Sigma_root, Q, P, J, KM, w_lb_est,
                 opt.set_xtol_abs(opt_dict['xtol_abs'])
                 opt.set_ftol_abs(opt_dict['ftol_abs'])
                 opt.set_maxeval(opt_dict['maxeval'])
-                x = opt.optimize(x0)
 
-                alert = opt.last_optimize_result() < 0 or opt.last_optimize_result() >= 5
-                flag = checkConstraints(x, dire, beta, Q, G, J, KM, QQ, p_int, 1e-2, 1e-2)
+                try:
+                    x = opt.optimize(x0)
+                    alert = opt.last_optimize_result() < 0 or opt.last_optimize_result() >= 5
+                    flag = checkConstraints(x, dire, beta, Q, G, J, KM, QQ, p_int, 1e-6, 1e-6)
+                except nlopt.RoundoffLimited:
+                    try:
+                        x = opt.optimize(x0)
+                        alert = opt.last_optimize_result() < 0 or opt.last_optimize_result() >= 5
+                        flag = checkConstraints(x, dire, beta, Q, G, J, KM, QQ, p_int, 1e-6, 1e-6)
+                    except nlopt.RoundoffLimited:
+                        alert = True
+                        flag = True
 
                 if alert is True or flag is True:
                     res_ub.append(numpy.nan)
@@ -858,7 +875,7 @@ def regularize_check(w, index_w, rho, verbose):
         index_w = w.loc[sel[0], ].index.get_level_values(0).tolist()
         if verbose:
             warnings.warn("Regularization paramater was too high (" + str(round(rho, 3)) + "). "
-                  + "We set it so that at least one component in w is non-zero.")
+                          + "We set it so that at least one component in w is non-zero.")
     return(index_w)
 
 
