@@ -16,33 +16,6 @@ from collections import Counter
 from .funs import complete_cases
 
 
-class scdata_output:
-    def __init__(self, A, B, C, P, Y_pre, Y_post, Y_donors, J, K, KM, M,
-                 cointegrated_data, period_pre, period_post, T0_features,
-                 T1_outcome, outcome_var, features, glob_cons, out_in_features):
-
-        self.A = A
-        self.B = B
-        self.C = C
-        self.P = P
-        self.Y_pre = Y_pre
-        self.Y_post = Y_post
-        self.Y_donors = Y_donors
-        self.J = J
-        self.K = K
-        self.KM = KM
-        self.M = M
-        self.cointegrated_data = cointegrated_data
-        self.period_pre = period_pre
-        self.period_post = period_post
-        self.T0_features = T0_features
-        self.T1_outcome = T1_outcome
-        self.outcome_var = outcome_var
-        self.features = features
-        self.glob_cons = glob_cons
-        self.out_in_features = out_in_features
-
-
 def scdata(df,
            id_var,
            time_var,
@@ -473,15 +446,15 @@ def scdata(df,
             # take into account empty covariate adjustemnt
             for m in range(len(features)):
                 if len(cov_adj[m]) == 0:
-                    i_start = len(rows_tr_pre) * m - 1
+                    i_start = len(rows_tr_pre) * m
                     zeros = pandas.DataFrame(numpy.zeros((len(rows_tr_pre), len(C.columns))),
                                              columns=C_names)
-                    if i_start < 0:
+                    if i_start == 0:
                         C_up = pandas.DataFrame(None)
                     else:
                         C_up = C.iloc[:i_start]
 
-                    C_bo = C.iloc[(i_start + 1):]
+                    C_bo = C.iloc[i_start:]
                     C = pandas.concat([C_up, zeros, C_bo]).reset_index(drop=True)
 
     if constant is True:
@@ -694,3 +667,29 @@ def scdata(df,
                          T0_features=T0_features, T1_outcome=T1,
                          outcome_var=outcome_var, features=features,
                          glob_cons=constant, out_in_features=out_in_features)
+
+class scdata_output:
+    def __init__(self, A, B, C, P, Y_pre, Y_post, Y_donors, J, K, KM, M,
+                 cointegrated_data, period_pre, period_post, T0_features,
+                 T1_outcome, outcome_var, features, glob_cons, out_in_features):
+
+        self.A = A
+        self.B = B
+        self.C = C
+        self.P = P
+        self.Y_pre = Y_pre
+        self.Y_post = Y_post
+        self.Y_donors = Y_donors
+        self.J = J
+        self.K = K
+        self.KM = KM
+        self.M = M
+        self.cointegrated_data = cointegrated_data
+        self.period_pre = period_pre
+        self.period_post = period_post
+        self.T0_features = T0_features
+        self.T1_outcome = T1_outcome
+        self.outcome_var = outcome_var
+        self.features = features
+        self.glob_cons = glob_cons
+        self.out_in_features = out_in_features
